<?php
if( !function_exists('growth_assets_setup') ){
    function growth_assets_setup(){
        /*
        * Make theme available for translation.
        * If you're building a theme based on growth, use a find and replace
        * to change 'growth' to the name of your theme in all the template files
        */
        load_theme_textdomain( 'growth', get_theme_file_path('/languages/') );
        
        // Add default posts and comments RSS feed links to head.
        add_theme_support( 'automatic-feed-links' );
        
        /*
        * Let WordPress manage the document title.
        * By adding theme support, we declare that this theme does not use a
        * hard-coded <title> tag in the document head, and expect WordPress to
        * provide it for us.
        */
        add_theme_support( 'title-tag' );
        
        /*
        * Enable support for custom logo.
        */
        add_theme_support( 'custom-logo', array(
            'flex-height' => true
        ) );
        
        
        if( class_exists( 'WooCommerce' ) ){   
            add_theme_support( 'woocommerce', 
                array(
                    'thumbnail_image_width' => 400,
                    'single_image_width'    => 800,
                    'product_grid' => array(
                        'default_rows'    => 4,
                        'min_rows'        => 1,
                        'max_rows'        => 6,
                        'default_columns' => 3,
                        'min_columns'     => 1,
                        'max_columns'     => 5,
                    ),
                )
            );
            add_theme_support( 'wc-product-gallery-zoom' );
            add_theme_support( 'wc-product-gallery-lightbox' );
            add_theme_support( 'wc-product-gallery-slider' );
        }

        // Setup the WordPress core custom background feature.
        /**
         * Filter growth custom-header support arguments.
         *
         * @since growth 1.0
         *
         * @param array $args {
         *     An array of custom-header support arguments.
         *
         *     @type string $default-color     		Default color of the header.
         *     @type string $default-attachment     Default attachment of the header.
         * }
         */
        add_theme_support( 
            'custom-background',
                apply_filters(
                    'growth_custom_background_args', array(
                        'default-color'      => 'ffffff'
                    )
            )
        );     
        
        // Setup the WordPress core custom header background feature.    
        add_theme_support( 'custom-header', apply_filters( 'growth_custom_header_args', array(
            'default-text-color'     => 'ffffff',
            'wp-head-callback'       => 'growth_header_style',
        ) ) );
        
        if ( ! function_exists( 'growth_header_style' ) ) {
           function growth_header_style() {
                $header_text_color = get_header_textcolor();
                if ( get_theme_support( 'custom-header', 'default-text-color' ) === $header_text_color ) {
                    return;
                }
            } 
        }        
        
        /*
        * Enable support for Post Thumbnails on posts and pages.
        *
        * @link https://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
        */
        add_theme_support( 'post-thumbnails' );
        add_image_size( 'growth-post-image', 1200, 800, array( 'center', 'center' ) );
        add_image_size( 'growth-tall-thumbnail', 300, 260, array( 'center', 'center' ) );


        // This theme uses wp_nav_menu() in two locations.
        register_nav_menus( array(
            'primary_menu' => esc_html__( 'Primary Menu', 'growth' ),
            'footer_menu'  => esc_html__( 'Footer Menu', 'growth' ),
        ) );

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support( 'html5', array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
        ) );

        /*
         * Enable support for Post Formats.
         *
         * See: https://codex.wordpress.org/Post_Formats
         */
        add_theme_support( 'post-formats', array(
            'aside',
            'image',
            'video',
            'quote',
            'link',
            'gallery',
            'status',
            'audio',
            'chat',
        ) );

        /*
         * This theme styles the visual editor to resemble the theme style,
         * specifically font, colors, icons, and column width.
         */
        add_editor_style( array( 'assets/css/editor-style.css' ) );    
        
        // Indicate widget sidebars can use selective refresh in the Customizer.
        add_theme_support( 'customize-selective-refresh-widgets' );
        
        
        // Used for OnePage Template Back Link 
        if( !function_exists('growth_detect_homepage') ){
            function growth_detect_homepage() {
                $onepage         = '';
                $onepage         = get_post_meta( get_the_ID(), '_growth_one_page_scroll', true );
                /*If front page is set to display a static page, get the URL of the posts page.*/
                $homepage_id     = get_option( 'page_on_front' );
                /*current page id*/
                $current_page_id = ( is_page( get_the_ID() ) ) ? get_the_ID() : '';
                if( $homepage_id == $current_page_id or $onepage == 'on'  ) {
                    return true;
                } else {
                    return false;
                }

            }
        }
        
    }
}
add_action( 'after_setup_theme','growth_assets_setup' );

/**
 * Sets the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 *
 * @since growth 1.0.0
 */
if( !function_exists('growth_content_width') ){    
    function growth_content_width() {
        $GLOBALS['content_width'] = apply_filters( 'growth_content_width', 750 );
    }
}
add_action( 'after_setup_theme', 'growth_content_width', 0 );

/**
 * Registers a widget area.
 *
 * @link https://developer.wordpress.org/reference/functions/register_sidebar/
 *
 * @since growth 1.0.0
 */
if( !function_exists('growth_widgets_init') ){
    function growth_widgets_init() {
        register_sidebar( array(
            'name'          => esc_html__( 'Sidebar', 'growth' ),
            'id'            => 'sidebar-1',
            'description'   => esc_html__( 'Add widgets here to appear in your sidebar.', 'growth' ),
            'before_widget' => '<section id="%1$s" class="widget %2$s">',
            'after_widget'  => '</section>',
            'before_title'  => '<h3 class="widget-title">',
            'after_title'   => '</h3>',
        ) );
        
        register_sidebar( array(
            'name'          => esc_html__( 'Footer Widget', 'growth' ),
            'id'            => 'sidebar-2',
            'description'   => esc_html__( 'Add footer bottom widgets.', 'growth' ),
            'before_widget' => '<section id="%1$s" class="widget footer-widget %2$s col-xs-12 col-sm-4 xs-full masonry-item">',
            'after_widget'  => '</section>',
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>',
        ) );
    }
}
add_action( 'widgets_init', 'growth_widgets_init' );

if ( !function_exists( 'growth_fonts_url' ) ) {
    /**
     * Register Google fonts for growth.
     *
     * Create your own growth_fonts_url() function to override in a child theme.
     *
     * @since growth 1.0
     *
     * @return string Google fonts URL for the theme.
     */
    function growth_fonts_url() {
        $fonts_url = '';
        $fonts     = array();
        $subsets   = 'latin,latin-ext';
        /* translators: If there are characters in your language that are not supported by Roboto, translate this to 'off'. Do not translate into your own language. */
        $fonts[] = 'Playfair+Display:400,700&display=swap';
        $fonts[] = 'Open+Sans:300,400,600,700';

        if ( $fonts ) {
            $fonts_url = add_query_arg( array(
                'family' =>  implode( '|', $fonts ),
                'subset' =>  $subsets,
            ), '//fonts.googleapis.com/css' );
        }
        return esc_url_raw($fonts_url);
    }
}

/**
 * Enqueues scripts and styles.
 *
 * @since growth 1.0.0
 */
if( !function_exists('growth_enqueue_scripts') ){
    function growth_enqueue_scripts() {
        if ( class_exists( 'Redux' ) ) {
            global $growth_opt;
        }else{
            $growth_opt                    = array();
            $growth_opt['menu_width']      = '1170';
            $growth_opt['loader_color']    = '#ffc576';
            $growth_opt['custom_css']      = '';
            $growth_opt['scrollUp_switch'] = true;
            $growth_opt['footer_gr_bg']    = array(
                'from' => '#313552',
                'to' => '#313552',
            );
        }
        $menu_text_color            = get_post_meta( get_the_ID(), '_growth_menu_text_color', true );
        $menu_hover_text_color      = get_post_meta( get_the_ID(), '_growth_menu_hover_text_color', true );
        $menu_item_active_bar_color = get_post_meta( get_the_ID(), '_growth_menu_item_active_bar_color', true );
        
        // Add google fonts, used in the main stylesheet.
        wp_enqueue_style( 'growth-fonts', growth_fonts_url(), array(), null );

        // Add Font-awesome, used for font icons.
        wp_enqueue_style( 'font-awesome-5', get_theme_file_uri('/assets/css/font-awesome-5.css'), array(), '1.0.1' );
        wp_enqueue_style( 'hkgrotesk', get_theme_file_uri('/assets/css/hkgrotesk.css'), array(), '1.0.1' );

        // Add Bootstrap, Used for default grid system.
        wp_enqueue_style( 'bootstrap', get_theme_file_uri('/assets/css/bootstrap-min.css'), array(), '3.3.7' );
        
            
        if( class_exists( 'WooCommerce' ) ){   
            // Add Bootstrap, Used for default grid system.
            wp_enqueue_style( 'growth-wc-style', get_theme_file_uri('/assets/css/wc-style.css'), array(), '3.3.7' );
        }
        
        
        // Add slick slider, Used for carousel slider.
        wp_enqueue_style( 'slick', get_theme_file_uri('/assets/css/slick.css'), array(), '1.0.10' );
        wp_enqueue_style( 'slick-theme', get_theme_file_uri('/assets/css/slick-theme.css'), array(), '1.0.10' );
        
        // Add slicknav, Used for responsive mobile menu.
        wp_enqueue_style( 'slicknav', get_theme_file_uri('/assets/css/slicknav.css'), array(), '1.0.10' );
        
        // Add growth Theme CSS, Used for important structure style.
        wp_enqueue_style( 'growth-theme', get_theme_file_uri('/assets/css/theme.css'), array(), '1.0.0' );
               
        // Add Normalizer, Used for remove default tag style.
        wp_enqueue_style( 'normalizer', get_theme_file_uri('/assets/css/normalize.css'), array(), '1.0.0' );
             
        // Theme stylesheet.
        wp_enqueue_style( 'growth-style', get_stylesheet_uri() );
                
        // Add responsive, Used for mobile style.
        wp_enqueue_style( 'growth-responsive', get_theme_file_uri('/assets/css/responsive.css'), array(), '1.0.0' );
        
        // Add html5shiv. Used for support html5 tag.
        wp_enqueue_script( 'html5shiv', get_theme_file_uri('/assets/js/vendor/html5shiv-min.js'), array(), '3.7.2' );
        wp_script_add_data( 'html5shiv', 'conditional', 'lt IE 9' );

        // Add respond. A polyfill is a browser fallback, made in JavaScript work in older browsers.
        wp_enqueue_script( 'respond', get_theme_file_uri('/assets/js/vendor/respond-min.js'), array(), '1.4.2' );
        wp_script_add_data( 'respond', 'conditional', 'lt IE 9' );
        
        // Add Bootstrap, Used for default normal effect.
        wp_enqueue_script( 'bootstrap', get_theme_file_uri('/assets/js/vendor/bootstrap-min.js'), array('jquery'), '3.3.7', true );
        
        // Add WordPress Default Masonry, Used for attach grid.
        wp_enqueue_script('jquery-masonry');
        
        // Add WordPress Default imagesloaded, Used for image load.        
        wp_enqueue_script('imagesloaded');
        
        // Add Slick Slider, Used for responsive carousel slider.
        wp_enqueue_script( 'slick', get_theme_file_uri('/assets/js/slick-min.js'), array('jquery'), '1.0.10', true );
        
        // Add SlickNav, Used for responsive mobile menu.
        wp_enqueue_script( 'slicknav', get_theme_file_uri('/assets/js/slicknav-min.js'), array('jquery'), '1.0.10', true );
        
        // Add jQuery-Fitvids, Used for responsive Video.
        wp_enqueue_script( 'jquery-fitvids', get_theme_file_uri('/assets/js/fitvids.js'), array('jquery'), '1.1.0', true );
        
        // Add jQuery-Fitvids, Used for responsive Video.
        wp_enqueue_script( 'jquery-prefixfree', get_theme_file_uri('/assets/js/prefixfree-min.js'), array('jquery'), '1.1.0', true );
        
        // Add jQuery-Fitvids, Used for responsive Video.
        wp_enqueue_script( 'growth-skip-link-focus-fix', get_theme_file_uri('/assets/js/skip-link-focus-fix.js'), array('jquery'), '1.1.0', true );
        
        if( $growth_opt['scrollUp_switch'] == true ):
            // Add scrollUp, Used for scrolling  button to top.
            wp_enqueue_script( 'scrollUp', get_theme_file_uri('/assets/js/scrollUp-min.js'), array('jquery'), '2.4.1', true );
        endif;
                   
        // Add scrollUp, Used for script activation
        wp_enqueue_script( 'growth-main', get_theme_file_uri('/assets/js/main.js'), array('jquery'), '1.0.0', true );  
        
        $custom_css = [];

        
        if( get_post_type() == 'page' and has_post_thumbnail() ){
            $custom_css[] = sprintf('.header-area { background-image: url(%s) }', esc_url(get_the_post_thumbnail_url()) );
        }elseif( !empty(get_header_image()) ){
            $custom_css[] = sprintf('.header-area { background-image: url(%s) }', esc_url(get_header_image()) );
        }
        
        
        if( !empty( $growth_opt['loader_color'] ) ){
            $custom_css[] = sprintf('            
            .preloader .loader span,
            .preloader .loader::before {
                background-color: %s;
            }            
            .preloader .loader::after {
                border: 5px solid %s;
            }
            
            ', $growth_opt['loader_color'],$growth_opt['loader_color']);
        }      
        if( !empty( $growth_opt['menu_width'] ) ){
            $custom_css[] = '.mainmenu-area .container { 
                max-width: 100%;
                width: '.$growth_opt['menu_width'].'px;
            }';
        }       
        if( !empty( $growth_opt['footer_gr_bg'] ) ){
            $custom_css[] = '.footer-area { 
                background-image:  linear-gradient(90deg, '.esc_attr($growth_opt['footer_gr_bg']['from']).' 0%, '.esc_attr($growth_opt['footer_gr_bg']['to']).' 100%) ;
            }';
        }  
                  
        if( !empty( $menu_text_color ) ){
            $custom_css[] = sprintf( '.mainmenu-area .primary-menu ul.nav > li > a, .transparent-menu .site-branding a, .site-branding a { color: %s }', esc_attr($menu_text_color)  );
        }  
        
        if( !empty( $menu_hover_text_color ) ){
            $custom_css[] = sprintf( 'body .mainmenu-area .primary-menu ul.nav > li:hover > a,body .mainmenu-area .primary-menu ul.nav > li.active > a, body .mainmenu-area .primary-menu ul.nav > li.current-menu-item > a { color: %s }', esc_attr($menu_hover_text_color)  );
        }    
        
        if( !empty( $menu_item_active_bar_color ) ){
            $custom_css[] = sprintf( '.primary-menu ul.nav > li.current-menu-item > a:before, .primary-menu ul.nav > li.active > a:before, .primary-menu ul.nav > li:hover > a:before { color: %s }', esc_attr($menu_item_active_bar_color)  );
            $custom_css[] = sprintf( '.mainmenu-area .primary-menu ul.nav .sub-menu li a:before { background-color: %s }', esc_attr($menu_item_active_bar_color)  );
        }    
        
        if( !empty( $growth_opt['custom_css'] ) ){
            $custom_css[] = $growth_opt['custom_css'];
        }
                
        $custom_css = implode( ' ', $custom_css );
        wp_add_inline_style( 'growth-style', $custom_css );        
        
        
        
        // Add comment reply script.
        if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
            wp_enqueue_script( 'comment-reply' );
        }
    }
}
add_action( 'wp_enqueue_scripts', 'growth_enqueue_scripts' );

// growth All Function Pack.
require get_theme_file_path('/inc/growth-function.php');
// Customizer Add Option.
require get_theme_file_path('/inc/customizer.php');
// Default Template Tag Functions.
require get_theme_file_path('/inc/template-tags.php');
// Important Plugin Activation.
require get_theme_file_path('/inc/growth-plugin-activation.php');
// OnePage Nav Waker Function.
require get_theme_file_path('/inc/nav-menu-walker.php');
// OnePage Nav Waker Function.
require get_theme_file_path('/inc/growth-option.php');
// Demo Content Importer.
if ( defined('FW') && file_exists( get_theme_file_path('/inc/importer.php') ) ) {
    require get_theme_file_path('/inc/importer.php');
}